## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = "center"
)

## ----packages-----------------------------------------------------------------
library(khroma)

## ----crameri_div_broc, fig.height=2, fig.width=7------------------------------
broc <- color("broc")
plot(broc(256))

## ----crameri_div_cork, fig.height=2, fig.width=7------------------------------
cork <- color("cork")
plot(cork(256))

## ----crameri_div_vik, fig.height=2, fig.width=7-------------------------------
vik <- color("vik")
plot(vik(256))

## ----crameri_div_lisbon, fig.height=2, fig.width=7----------------------------
lisbon <- color("lisbon")
plot(lisbon(256))

## ----crameri_div_tofino, fig.height=2, fig.width=7----------------------------
tofino <- color("tofino")
plot(tofino(256))

## ----crameri_div_berlin, fig.height=2, fig.width=7----------------------------
berlin <- color("berlin")
plot(berlin(256))

## ----crameri_div_roma, fig.height=2, fig.width=7------------------------------
roma <- color("roma")
plot(roma(256))

## ----crameri_div_bam, fig.height=2, fig.width=7-------------------------------
bam <- color("bam")
plot(bam(256))

## ----crameri_div_vanimo, fig.height=2, fig.width=7----------------------------
vanimo <- color("vanimo")
plot(vanimo(256))

## ----crameri_seq_batlow, fig.height=2, fig.width=7----------------------------
batlow <- color("batlow")
plot(batlow(256))

## ----crameri_seq_batlowW, fig.height=2, fig.width=7---------------------------
batlowW <- color("batlowW")
plot(batlowW(256))

## ----crameri_seq_batlowK, fig.height=2, fig.width=7---------------------------
batlowK <- color("batlowK")
plot(batlowK(256))

## ----crameri_seq_devon, fig.height=2, fig.width=7-----------------------------
devon <- color("devon")
plot(devon(256))

## ----crameri_seq_lajolla, fig.height=2, fig.width=7---------------------------
lajolla <- color("lajolla")
plot(lajolla(256))

## ----crameri_seq_bamako, fig.height=2, fig.width=7----------------------------
bamako <- color("bamako")
plot(bamako(256))

## ----crameri_seq_davos, fig.height=2, fig.width=7-----------------------------
davos <- color("davos")
plot(davos(256))

## ----crameri_seq_bilbao, fig.height=2, fig.width=7----------------------------
bilbao <- color("bilbao")
plot(bilbao(256))

## ----crameri_seq_nuuk, fig.height=2, fig.width=7------------------------------
nuuk <- color("nuuk")
plot(nuuk(256))

## ----crameri_seq_oslo, fig.height=2, fig.width=7------------------------------
oslo <- color("oslo")
plot(oslo(256))

## ----crameri_seq_grayC, fig.height=2, fig.width=7-----------------------------
grayC <- color("grayC")
plot(grayC(256))

## ----crameri_seq_hawaii, fig.height=2, fig.width=7----------------------------
hawaii <- color("hawaii")
plot(hawaii(256))

## ----crameri_seq_lapaz, fig.height=2, fig.width=7-----------------------------
lapaz <- color("lapaz")
plot(lapaz(256))

## ----crameri_seq_tokyo, fig.height=2, fig.width=7-----------------------------
tokyo <- color("tokyo")
plot(tokyo(256))

## ----crameri_seq_buda, fig.height=2, fig.width=7------------------------------
buda <- color("buda")
plot(buda(256))

## ----crameri_seq_acton, fig.height=2, fig.width=7-----------------------------
acton <- color("acton")
plot(acton(256))

## ----crameri_seq_turku, fig.height=2, fig.width=7-----------------------------
turku <- color("turku")
plot(turku(256))

## ----crameri_seq_imola, fig.height=2, fig.width=7-----------------------------
imola <- color("imola")
plot(imola(256))

## ----crameri_seq_oleron, fig.height=2, fig.width=7----------------------------
oleron <- color("oleron")
plot(oleron(256))

## ----crameri_seq_bukavu, fig.height=2, fig.width=7----------------------------
bukavu <- color("bukavu")
plot(bukavu(256))

## ----crameri_seq_fes, fig.height=2, fig.width=7-------------------------------
fes <- color("fes")
plot(fes(256))

